"""Built-in plugins for hexDAG framework.

This module contains built-in implementations of nodes, adapters, tools,
policies, and observers that ship with hexDAG. All components in this
module are registrable plugins with namespace="core".
"""
